pub fn validate_rotation_for_spec(
catalog: &ContentCatalog,
spec_id: SpecId,
rotation: &Rotation,
) -> Result<CheckResult, ApplicationError>Expand description
Resolve every name referenced by rotation against one specialization.
pub fn validate_rotation_for_spec(
catalog: &ContentCatalog,
spec_id: SpecId,
rotation: &Rotation,
) -> Result<CheckResult, ApplicationError>Resolve every name referenced by rotation against one specialization.